%This is a Matlab script developed by Konstantinos Glynis
%based on the analysis of (https://www.itia.ntua.gr/el/docinfo/2079/)
%K. Glynis, T. Iliopoulou, P. Dimitriadis, and D. Koutsoyiannis, Stochastic investigation 
%of daily air temperature extremes from a global ground station network

function [Kappa1,Kappa2,Kappa3,Kappa4] = K_calc_2(T,tail)

Ts = T(:,4);
if tail == 1 %Upper tail
    Ts = sort(Ts,'ascend'); %Sort in ascending order
else         %Lower tail
    Ts = sort(Ts,'descend'); %Sort in descending order
end
n = numel(Ts); %actual length of time series
temp2 = 0;
telos = min([max(find(Ts==max(Ts), 1, 'first'),find(Ts==min(Ts), 1, 'first')) n]);
for p = [1096 3653 7305 telos]
    stath = log(p)+gammaln(telos-p+1)-log(telos)-gammaln(telos);
    clear term;
    for i = 1:telos;
        if i >= p
            term(i) = exp(stath+gammaln(i)-gammaln(i-p+1))*Ts(i);
        else
            term(i) = 0;
        end
    end
    temp2 = temp2+1;
    Kp(temp2) = nansum(term);
end

if abs(Kp(1)) >= 0.5;
    Kappa1 = Kp(1);
else
    Kappa1 = NaN;
end
if abs(Kp(2)) >= 0.5;
    Kappa2 = Kp(2);
else
    Kappa2 = NaN;
end
if abs(Kp(3)) >= 1;
    Kappa3 = Kp(3);
else
    Kappa3 = NaN;
end
if abs(Kp(4)) >= 1;
    Kappa4 = Kp(4);
else
    Kappa4 = NaN;
end

end